==> jpmml-sklearn-1.5.14-sources.jar: sklearn2pmml/preprocessing/h2o/H2OFrameCreator.java <==
/*
 * Copyright (c) 2018 Villu Ruusmann
 *
 * This file is part of JPMML-SkLearn
 *
 * JPMML-SkLearn is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JPMML-SkLearn is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with JPMML-SkLearn.  If not, see <http://www.gnu.org/licenses/>.
 */
package sklearn2pmml.preprocessing.h2o;

import java.util.List;

import org.jpmml.converter.Feature;
import org.jpmml.sklearn.FeatureList;
import org.jpmml.sklearn.SkLearnEncoder;
import sklearn.MultiTransformer;

public class H2OFrameCreator extends MultiTransformer {

	public H2OFrameCreator(String module, String name){
		super(module, name);
	}

	@Override
	public List<Feature> encodeFeatures(List<Feature> features, SkLearnEncoder encoder){
		List<String> columnNames = getColumnNames();

		if(columnNames != null){
			FeatureList namedFeatures = new FeatureList(features, columnNames);

			return namedFeatures;
		}

		return features;
	}

	public List<String> getColumnNames(){
		Object columnNames = getOptionalObject("column_names");

		if(columnNames != null){
			return getList("column_names", String.class);
		}

		return null;
	}
}

==> jpmml-sklearn-1.6.23-sources.jar: sklearn2pmml/preprocessing/h2o/H2OFrameCreator.java <==
/*
 * Copyright (c) 2018 Villu Ruusmann
 *
 * This file is part of JPMML-SkLearn
 *
 * JPMML-SkLearn is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JPMML-SkLearn is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with JPMML-SkLearn.  If not, see <http://www.gnu.org/licenses/>.
 */
package sklearn2pmml.preprocessing.h2o;

import java.util.List;

import org.jpmml.converter.Feature;
import org.jpmml.sklearn.FeatureList;
import org.jpmml.sklearn.SkLearnEncoder;
import sklearn.MultiTransformer;

public class H2OFrameCreator extends MultiTransformer {

	public H2OFrameCreator(String module, String name){
		super(module, name);
	}

	@Override
	public List<Feature> encodeFeatures(List<Feature> features, SkLearnEncoder encoder){
		List<String> columnNames = getColumnNames();

		if(columnNames != null){
			FeatureList namedFeatures = new FeatureList(features, columnNames);

			return namedFeatures;
		}

		return features;
	}

	public List<String> getColumnNames(){
		Object columnNames = getOptionalObject("column_names");

		if(columnNames != null){
			return getListLike("column_names", String.class);
		}

		return null;
	}
}
